@@ -14,7 +14,10 @@ use sqlx::postgres::{PgConnectOptions, PgSslMode};
 use tracing_subscriber::filter::LevelFilter;
 
 #[derive(serde::Deserialize, Debug)]
+#[serde(deny_unknown_fields)]
 pub struct Settings {
+    #[serde(default)]
+    pub environment: Environment,
     pub database: DatabaseSettings,
     pub application: AuditorSettings,
     #[serde(default = "default_metrics")]
@@ -27,9 +30,10 @@ pub struct Settings {
 
 // Set the default values for TLSConfig options
 #[derive(serde::Deserialize, Debug)]
+#[serde(deny_unknown_fields)]
 pub struct TLSConfig {
     pub use_tls: bool,
-    pub https_addr: Option<String>,
+    pub https_addr: Option<Vec<String>>,
     #[serde(default = "default_https_port")]
     pub https_port: u16,
     pub ca_cert_path: Option<String>,
@@ -62,7 +66,7 @@ impl TLSConfig {
 #[derive(Debug)]
 pub struct TLSParams {
     pub config: ServerConfig,
-    pub https_addr: Option<String>,
+    pub https_addr: Option<Vec<String>>,
     pub https_port: u16,
     pub use_tls: bool,
 }
@@ -72,18 +76,31 @@ fn default_log_level() -> LevelFilter {
 }
 
 #[derive(serde::Deserialize, Debug)]
+#[serde(deny_unknown_fields)]
 pub struct AuditorSettings {
     #[serde(default = "default_addr")]
-    pub addr: String,
+    pub addr: Vec<String>,
     #[serde(deserialize_with = "deserialize_number_from_string")]
     pub port: u16,
+    #[serde(default = "default_workers")]
+    pub web_workers: usize,
 }
 
-fn default_addr() -> String {
-    "127.0.0.1".to_string()
+fn default_addr() -> Vec<String> {
+    vec!["127.0.0.1".to_string()]
+}
+
+fn default_workers() -> usize {
+    if let Ok(num) = std::thread::available_parallelism() {
+        std::cmp::min(num.get(), 4)
+    } else {
+        tracing::warn!("Cannot determine how many web workers to use. Fall back to 2.");
+        2
+    }
 }
 
 #[derive(serde::Deserialize, Debug)]
+#[serde(deny_unknown_fields)]
 pub struct DatabaseSettings {
     pub username: String,
     pub password: Secret<String>,
@@ -95,12 +112,14 @@ pub struct DatabaseSettings {
 }
 
 #[derive(serde::Deserialize, Debug)]
+#[serde(deny_unknown_fields)]
 pub struct MetricsSettings {
     pub database: DatabaseMetricsSettings,
 }
 
 #[serde_with::serde_as]
 #[derive(serde::Deserialize, Debug)]
+#[serde(deny_unknown_fields)]
 pub struct DatabaseMetricsSettings {
     #[serde(default = "default_db_metrics_frequency")]
     #[serde_as(as = "serde_with::DurationSeconds<i64>")]
@@ -159,9 +178,11 @@ pub fn get_configuration() -> Result<Settings, config::ConfigError> {
     };
 
     let environment: Environment = std::env::var("AUDITOR_ENVIRONMENT")
-        .unwrap_or_else(|_| "local".into())
-        .try_into()
-        .expect("Failed to parse AUDITOR_ENVIRONMENT.");
+        .ok()
+        .map(Environment::try_from)
+        .transpose()
+        .map_err(config::ConfigError::Message)?
+        .unwrap_or_default();
 
     let settings = config::Config::builder()
         .add_source(config::File::from(configuration_directory.join("base")).required(false))
@@ -181,14 +202,20 @@ pub fn get_configuration() -> Result<Settings, config::ConfigError> {
     let settings = settings.add_source(
         config::Environment::with_prefix("AUDITOR")
             .separator("__")
-            .prefix_separator("_"),
+            .prefix_separator("_")
+            .list_separator(",")
+            .with_list_parse_key("application.addr")
+            .try_parsing(true),
     );
 
     settings.build()?.try_deserialize()
 }
 
 // The possible runtime environment for AUDITOR.
+#[derive(serde::Deserialize, Debug, Default)]
+#[serde(try_from = "String")]
 pub enum Environment {
+    #[default]
     Local,
     Production,
 }
