@@ -6,19 +6,21 @@
 // copied, modified, or distributed except according to those terms.
 
 mod component;
+mod meta;
 mod record;
 mod score;
 mod validamount;
-mod validfactor;
 mod validname;
+mod validvalue;
 
-use actix_web::{http::StatusCode, ResponseError};
+use actix_web::{ResponseError, http::StatusCode};
 pub use component::{Component, ComponentTest};
-pub use record::{Record, RecordAdd, RecordTest, RecordUpdate};
+pub use meta::{Meta, ValidMeta};
+pub use record::{Record, RecordAdd, RecordDatabase, RecordTest, RecordUpdate};
 pub use score::{Score, ScoreTest};
 pub use validamount::ValidAmount;
-pub use validfactor::ValidFactor;
 pub use validname::ValidName;
+pub use validvalue::ValidValue;
 
 use crate::error::error_chain_fmt;
 
